==> isis-fish-4.1.0.1-sources.jar: fr/ifremer/isisfish/ui/models/export/ExportListModel.java <==
/*
 * #%L
 * IsisFish
 * 
 * $Id: ExportListModel.java 3124 2010-11-29 18:14:09Z chatellier $
 * $HeadURL$
 * %%
 * Copyright (C) 2009 - 2010 Ifremer, Code Lutin
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 2 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-2.0.html>.
 * #L%
 */

package fr.ifremer.isisfish.ui.models.export;

import java.util.List;

import javax.swing.AbstractListModel;

import fr.ifremer.isisfish.export.Export;

/**
 * Model pour la liste des instances d'exports.
 *
 * @author chatellier
 * @version $Revision: 3124 $
 * 
 * Last update : $Date: 2010-11-29 19:14:09 +0100 (Mon, 29 Nov 2010) $
 * By : $Author: chatellier $
 */
public class ExportListModel extends AbstractListModel {

    /** serialVersionUID. */
    private static final long serialVersionUID = -4070846632975105788L;

    protected List<Export> exports;

    /**
     * Empty constructor.
     */
    public ExportListModel() {
        this(null);
    }

    /**
     * Constructor with plan list.
     * 
     * @param exports exports
     */
    public ExportListModel(List<Export> exports) {
        super();
        setExport(exports);
    }

    /**
     * Get exports list.
     * 
     * @return the exports
     */
    public List<Export> getExports() {
        return exports;
    }

    /**
     * Set exports list.
     * 
     * @param exports the exports to set
     */
    public void setExport(List<Export> exports) {
        this.exports = exports;
    }

    /*
     * @see javax.swing.ListModel#getElementAt(int)
     */
    @Override
    public Object getElementAt(int index) {
        return exports.get(index);
    }

    /*
     * @see javax.swing.ListModel#getSize()
     */
    @Override
    public int getSize() {
        int size = 0;

        if (exports != null) {
            size = exports.size();
        }
        return size;
    }
}

==> isis-fish-4.3.0.2-20140616.104318-1-sources.jar: fr/ifremer/isisfish/ui/models/export/ExportListModel.java <==
/*
 * #%L
 * IsisFish
 * 
 * $Id: ExportListModel.java 3969 2014-04-17 16:48:13Z echatellier $
 * $HeadURL$
 * %%
 * Copyright (C) 2009 - 2010 Ifremer, Code Lutin
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * #L%
 */

package fr.ifremer.isisfish.ui.models.export;

import java.util.List;

import javax.swing.AbstractListModel;

import fr.ifremer.isisfish.export.Export;

/**
 * Model pour la liste des instances d'exports.
 *
 * @author chatellier
 * @version $Revision: 3969 $
 * 
 * Last update : $Date: 2014-04-17 18:48:13 +0200 (jeu., 17 avril 2014) $
 * By : $Author: echatellier $
 */
public class ExportListModel extends AbstractListModel<Export> {

    /** serialVersionUID. */
    private static final long serialVersionUID = -4070846632975105788L;

    protected List<Export> exports;

    /**
     * Empty constructor.
     */
    public ExportListModel() {
        this(null);
    }

    /**
     * Constructor with plan list.
     * 
     * @param exports exports
     */
    public ExportListModel(List<Export> exports) {
        setExport(exports);
    }

    /**
     * Get exports list.
     * 
     * @return the exports
     */
    public List<Export> getExports() {
        return exports;
    }

    /**
     * Set exports list.
     * 
     * @param exports the exports to set
     */
    public void setExport(List<Export> exports) {
        this.exports = exports;
    }

    /*
     * @see javax.swing.ListModel#getElementAt(int)
     */
    @Override
    public Export getElementAt(int index) {
        return exports.get(index);
    }

    /*
     * @see javax.swing.ListModel#getSize()
     */
    @Override
    public int getSize() {
        int size = 0;

        if (exports != null) {
            size = exports.size();
        }
        return size;
    }
}
